@@ -596,7 +596,7 @@ prep_data <- function(data,
   }
 
   if (fes) {
-    fe_dat <- as.data.frame(data[["fixed_effects"]])
+    fe_dat <- as.data.frame(data[["fixed_effects"]], stringsAsFactors=TRUE)
     fe_levels <- vapply(fe_dat, nlevels, 0L)
     if (any(fe_levels == 1)) {
       if (ncol(fe_dat) != 1) {
